@@ -22,14 +22,21 @@ test("CSSStyleDeclaration", function(){
 	equal(d.getPropertyValue("color"), "purple");
 	equal(d.getPropertyValue("width"), "128px");
 	equal(d.getPropertyValue("position"), "");
-	
+
 	strictEqual(d.getPropertyPriority("color"), "");
 	strictEqual(d.getPropertyPriority("width"), "important");
 	strictEqual(d.getPropertyPriority("position"), "");
-	
+
 	d.setProperty("color", "green");
 	d.removeProperty("width");
-	
+
 	equal(d.cssText, "color: green;");
 
 });
+
+test("CSSStyleDeclaration#cssText", function(){
+	var d = new CSSOM.CSSStyleDeclaration;
+	var cssText = "color: pink; outline: 2px solid red;";
+	d.cssText = cssText;
+	strictEqual(d.cssText, cssText);
+});
